{% load evelinks %}
{% load i18n %}

<div class="accordion-item">
    <div class="accordion-header clearfix position-relative" id="heading{{ value.0 }}">
        <span
            class="accordion-button collapsed"
            type="button"
            data-bs-toggle="collapse"
            data-bs-target="#collapse{{ value.0 }}"
            aria-expanded="false"
            aria-controls="collapse{{ value.0 }}"
        >
            <img class="rounded me-3" src="{{ value.0|alliance_logo_url:32 }}" alt="{{ key }}">

            <span class="d-block" style="width: calc(100% - 113px);">
                {{ key }}
            </span>
        </span>

        {% if key != 'No Alliance' %}
            <a
                class="btn btn-primary btn-sm position-absolute btn-alliance-statistics"
                href="{% url 'afat:statistics_alliance' value.0 %}"
                data-bs-toggle="tooltip"
                data-bs-html="true"
                data-bs-title="{% translate 'Alliance statistics for' %}:<br>{{ key }}"
                style="top: 17px; right: 50px; z-index: 999;"
            >
                <i class="fa-solid fa-eye" style="color: rgb(255 255 255);"></i>
            </a>
        {% endif %}
    </div>

    {% include "afat/partials/statistics/overview/tabs/corp-list.html" %}
</div>
