# Generated by Django 4.0.10 on 2023-04-21 21:58

# Django
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("afat", "0021_alter_afatlink_fleet"),
    ]

    operations = [
        migrations.AddField(
            model_name="afatlink",
            name="esi_error_count",
            field=models.IntegerField(default=0),
        ),
        migrations.AddField(
            model_name="afatlink",
            name="last_esi_error",
            field=models.CharField(
                blank=True,
                choices=[
                    (
                        "NOT_IN_FLEET",
                        "FC is not in the registered fleet anymore or fleet is no longer available.",
                    ),
                    ("NO_FLEET", "Registered fleet seems to be no longer available."),
                    ("NOT_FLEETBOSS", "FC is no longer the fleet boss."),
                ],
                default="",
                max_length=15,
            ),
        ),
        migrations.AddField(
            model_name="afatlink",
            name="last_esi_error_time",
            field=models.DateTimeField(blank=True, default=None, null=True),
        ),
        migrations.AlterField(
            model_name="afatlink",
            name="is_registered_on_esi",
            field=models.BooleanField(
                default=False,
                help_text="Whether the fleet to this FAT link is available in ESI or not",
            ),
        ),
    ]
