{% for key, value in characters.items %}
    <tr>
        <td>{{ key }}</td>
        <td>{{ value.0 }}</td>
        <td class="text-end">
            <a class="btn btn-primary btn-sm" href="{% url 'afat:statistics_character' value.1 year month %}">
                <i class="fa-solid fa-eye"></i>
            </a>
        </td>
    </tr>
{% endfor %}
