{% load django_bootstrap5 %}
{% load i18n %}

<div class="col-md-6 ml-md-2">
    <div class="card card-default">
        <div class="card-header">
            <div class="card-title mb-0">
                {% translate "Create a clickable FAT link" %}
            </div>
        </div>

        <div class="card-body">
            <p>
                {% translate "This option will create a clickable link to share with your fleet members." %}
            </p>

            <!-- Form Goes Here -->
            <form class="form" role="form" action="{% url 'afat:fatlinks_create_clickable_fatlink' %}" method="POST">
                {% csrf_token %}

                {% bootstrap_field manual_fatlink_form.name %}
                {% bootstrap_field manual_fatlink_form.type %}
                {% bootstrap_field manual_fatlink_form.doctrine %}
                {% bootstrap_field manual_fatlink_form.duration %}

                {% include "afat/partials/form/required-field-hint.html" %}

                <div class="form-group text-end">
                    <button class="btn btn-primary" type="submit" name="submit_click">
                        <span class="fa fa-plus fa-fw"></span>

                        {% translate "Create link" %}
                    </button>
                </div>
            </form>
        </div>
    </div>
</div>
