# Generated by Django 3.1.1 on 2020-10-04 00:04

# Django
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("afat", "0011_change_meta_options_on_manualafat_20201003_2222"),
    ]

    operations = [
        migrations.AddField(
            model_name="manualafat",
            name="created_at",
            field=models.DateTimeField(
                blank=True, help_text="Time this FAT has been added manually", null=True
            ),
        ),
    ]
