{% if doctrines|length > 0 %}
    <datalist id="afat-fleet-doctrine-list">
        {% for doctrine in doctrines %}
            <option value="{{ doctrine.name }}">{{ doctrine.name }}</option>
        {% endfor %}
    </datalist>
{% endif %}
