{% for main_char in main_chars.items %}
    {% for main in main_char %}
        {% if main.name %}
            <tr>
                <td>
                    {{ main.name }}

{#                    {% if corp.corporation_id != main.corporation_id %}#}
{#                        ({{ main.corporation_name }})#}
{#                    {% endif %}#}
                </td>

                <td class="text-end">{{ main.fats }}</td>

                <td class="text-end">
                    <button
                        class="btn btn-primary btn-sm btn-afat-corp-stats-view-character"
                        data-character-name="{{ main.name }}"
                        data-character-id="{{ main.id }}"
                        data-year="{{ year }}"
                        data-month="{{ month }}"
                        data-url="{% url 'afat:statistics_ajax_get_monthly_fats_for_main_character' corp.corporation_id main.id year month %}"
                    >
                        <i class="fa-solid fa-eye"></i>
                    </button>
                </td>
            </tr>
        {% endif %}
    {% endfor %}
{% endfor %}
