{% load i18n %}

<ul class="nav nav-tabs">
    <li class="nav-item" role="presentation">
        <a
            class="nav-link active"
            id="fats"
            data-bs-toggle="tab"
            href="#tab-fats"
            role="tab"
            aria-controls="tab-fats"
            aria-selected="true"
        >
            {% translate "FATs" %}
        </a>
    </li>

    <li>
        <a
            class="nav-link"
            id="fatlinks"
            data-bs-toggle="tab"
            href="#tab-fatlinks"
            role="tab"
            aria-controls="tab-fatlinks"
            aria-selected="false"
        >
            {% translate "FAT links" %}
        </a>
    </li>
</ul>
