{% load i18n %}

<!-- AFAT Modal -->
<div class="modal fade" id="{{ modal_name }}Modal" tabindex="-1" role="dialog" aria-labelledby="{{ modal_name }}ModalTitle" aria-hidden="true">
    <div class="modal-dialog modal-dialog-centered" role="document">
        <div class="modal-content">
            <div class="modal-header">
                <div class="modal-title fs-5" id="{{ modal_name }}ModalLongTitle">
                    {{ modal_title }}
                </div>

                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="{% translate 'Close' %}"></button>
            </div>

            <div class="modal-body"></div>

            <div class="modal-footer">
                <button type="button" id="cancel-action" class="btn btn-secondary btn-sm" data-bs-dismiss="modal"></button>

                <a id="confirm-action" class="btn {% if confirm_button_class %}{{ confirm_button_class }}{% else %}btn-primary{% endif %} btn-sm" role="button" href=""></a>
            </div>
        </div>

        <div id="defaultTexts" class="d-none">
            <span id="cancelButtonDefaultText">{% translate "Cancel" %}</span>
            <span id="confirmButtonDefaultText">{% translate "Confirm" %}</span>
        </div>
    </div>
</div>
