{% load i18n %}

<ul class="nav nav-tabs">
    {% translate "Graphs" as tab_title %}
    {% include "afat/partials/common/navigation/tab.html" with is_active_tab=True tab_id="graphs" tab_title=tab_title %}

    {% translate "Corporations" as tab_title %}
    {% include "afat/partials/common/navigation/tab.html" with is_active_tab=False tab_id="members" tab_title=tab_title %}
</ul>
