"""
App config
"""

# Django
from django.utils.translation import gettext_lazy as _

__version__ = "3.12.3"
__title__ = _("Fleet Activity Tracking")

__package_name__ = "allianceauth-afat"
__app_name__ = "afat"
__app_name_verbose__ = "Alliance Auth AFAT"
__app_name_useragent__ = "Alliance-Auth-AFAT"

__github_url__ = f"https://github.com/ppfeufer/{__package_name__}"
