{% if fleet_types|length > 0 %}
    <datalist id="afat-fleet-type-list">
        {% for fleet_type in fleet_types %}
            <option value="{{ fleet_type.name }}">{{ fleet_type.name }}</option>
        {% endfor %}
    </datalist>
{% endif %}
