{% load i18n %}

<div id="tab-fatlinks" class="tab-pane fade card card-default border-0" role="tabpanel" aria-labelledby="tab-fatlinks">
    <div class="card-body">
        <h4>
            {% translate "Most recent FAT links <small>(latest 10)</small>" %}
        </h4>

        <table class="table table-striped table-hover no-footer w-100" id="dashboard-recent-fatlinks">
            <thead>
                <tr>
                    <th>{% translate "Fleet name" %}</th>
                    <th>{% translate "Fleet type" %}</th>
                    <th>{% translate "Doctrine" %}</th>
                    <th>{% translate "Creator" %}</th>
                    <th>{% translate "EVE time" %}</th>

                    {# Display the "Actions" column only if the user has the 'add_fatlink' or 'manage_afat' permission. #}
                    {% if perms.afat.add_fatlink or perms.afat.manage_afat %}
                        <th><!-- {% translate "Actions" %} --></th>
                    {% endif %}
                </tr>
            </thead>

            <tbody></tbody>

            <tfoot>
                <tr>
                    <td colspan="{% if perms.afat.add_fatlink or perms.afat.manage_afat %}6{% else %}5{% endif %}">
                        {% include "afat/partials/fatlinks/fatlink-list-legend.html" %}
                    </td>
                </tr>
            </tfoot>
        </table>
    </div>
</div>
