{% load i18n %}

<p class="fatlink-list-legend my-3 py-3 border-top">
    <b>{% translate "Legend" %}:</b><br>
    <span class="badge text-bg-success afat-label">{% translate "ESI" %}</span> » {% translate "Fleet is currently active and FATs are automatically being tracked via ESI" %}<br>
    <span class="badge text-bg-secondary afat-label">{% translate "ESI" %}</span> » {% translate "FATs have been automatically tracked via ESI" %}
</p>
