{% load evelinks %}
{% load i18n %}

<div
    id="collapse{{ value.0 }}"
    class="accordion-collapse collapse"
    aria-labelledby="heading{{ value.0 }}"
    data-bs-parent="#accordionAlliances"
>
    <div class="accordion-body">
        <table class="table table-striped table-hover mb-0">
            <tbody>
                {% for corp in value %}
                    {% if not forloop.first %}
                        <tr>
                            <td>
                                <img
                                    class="rounded me-3"
                                    src="{{ corp.0|corporation_logo_url:32 }}"
                                    alt="{{ corp.1 }}"
                                >
                                {{ corp.1 }}
                            </td>

                            <td class="text-end">
                                <a
                                    class="btn btn-primary btn-sm"
                                    href="{% url 'afat:statistics_corporation' corp.0 %}"
                                    data-bs-toggle="tooltip"
                                    data-bs-html="true"
                                    data-bs-title="{% translate 'Corporation statistics for' %}:<br>{{ corp.1 }}"
                                >
                                    <i class="fa-solid fa-eye"></i>
                                </a>
                            </td>
                        </tr>
                    {% endif %}
                {% endfor %}
            </tbody>
        </table>
    </div>
</div>
