{% load i18n %}

<ul class="nav nav-tabs">
    {% translate "My Stats" as tab_title %}
    {% include "afat/partials/common/navigation/tab.html" with is_active_tab=True tab_id="mine" tab_title=tab_title %}

    {% if perms.afat.stats_corporation_own or perms.afat.stats_corporation_other or perms.afat.manage_afat %}
        {% translate "Corporations" as tab_title %}
        {% include "afat/partials/common/navigation/tab.html" with is_active_tab=False tab_id="corps" tab_title=tab_title %}
    {% endif %}
</ul>
