{% load i18n %}

<table class="table table-striped table-hover w-100" id="{{ id }}">
    <thead>
        <tr>
            <th>{% translate "Character" %}</th>
            <th class="text-end">{% translate "FATs" %}</th>
            <th><!-- {% translate "Character statistics" %} --></th>

            {% if id == "character-alt-characters" %}
                <th>
                    {% comment %}
                        Status check: In Main Corp
                    {% endcomment %}
                </th>
            {% endif %}
        </tr>
    </thead>

    <tbody>
        {% if character_data_template %}
            {% include "afat/partials/statistics/character/tables/data/character-fats/"|add:character_data_template|add:".html" %}
        {% endif %}
    </tbody>
</table>
