<li class="nav-item" role="presentation">
    <a
        class="nav-link{% if is_active_tab %} active{% endif %}"
        id="{{ tab_id }}"
        data-bs-toggle="tab"
        href="#tab-{{ tab_id }}"
        role="tab"
        aria-controls="tab-{{ tab_id }}"
        aria-selected="{% if is_active_tab %}true{% else %}false{% endif %}"
    >
        {{ tab_title }}
    </a>
</li>
