{% load evelinks %}

<li class="nav-item afat-character-tab text-center">
    <a
        class="{{ tab_class|default:'nav-link' }}{% if forloop.first %} active{% endif %}"
        id="tab-{{ character_id }}"
        data-bs-toggle="tab"
        href="#content-{{ character_id }}"
        role="tab"
        aria-controls="content-{{ character_id }}"
        aria-selected="{% if forloop.first %}true{% else %}false{% endif %}"
    >
        <img class="rounded" src="{{ character_id|character_portrait_url:64 }}" alt="{{ character_name }}" width="48px" height="48px">
        <span class="d-block" id="afat-eve-character-id-{{ character_id }}">{{ character_name }}</span>
    </a>
</li>
