# Generated by Django 4.2.20 on 2025-04-11 14:36

# Django
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("afat", "0024_setting_doctrine_and_fleet_type"),
    ]

    operations = [
        migrations.AddField(
            model_name="fat",
            name="alliance_eve_id",
            field=models.BigIntegerField(
                help_text="Alliance EVE ID of the character who registered this FAT at the time of registration",
                null=True,
            ),
        ),
        migrations.AddField(
            model_name="fat",
            name="corporation_eve_id",
            field=models.BigIntegerField(
                help_text="Corporation EVE ID of the character who registered this FAT at the time of registration",
                null=True,
            ),
        ),
    ]
