{% load django_bootstrap5 %}
{% load i18n %}
{% load evelinks %}

<div class="col-md-6 mr-md-1">
    <div class="card card-default">
        <div class="card-header">
            <div class="card-title mb-0">
                {% translate "Create a FAT link using ESI" %}
            </div>
        </div>

        <div class="card-body">
            <p>
                {% blocktranslate %}
                    This option will automatically register and track the entire fleet
                    without fleet members having to click a link. <b>Use this if you
                    are the Fleet Boss</b>, otherwise please use the clickable FAT link
                    option.
                {% endblocktranslate %}
            </p>

            <p>
                {% blocktranslate %}
                    This will start tracking your fleet automatically and add pilots to
                    it as they join until the fleet is either closed in-game
                    (meaning you leave the fleet), or you stop the tracking here.
                {% endblocktranslate %}
            </p>

            {% include "afat/partials/fatlinks/open-esi-fleets.html" %}

            <form class="form" role="form" action="{% url 'afat:fatlinks_create_esi_fatlink' %}" method="POST">
                {% csrf_token %}

                {% bootstrap_field esi_fatlink_form.name_esi %}
                {% bootstrap_field esi_fatlink_form.type_esi %}
                {% bootstrap_field esi_fatlink_form.doctrine_esi %}

                {% include "afat/partials/form/required-field-hint.html" %}

                <div class="form-group text-end">
                    <button class="btn btn-primary" type="submit" name="submit_click">
                        <span class="fa fa-plus fa-fw"></span>

                        {% translate "Add ESI link" %}
                    </button>
                </div>
            </form>
        </div>
    </div>
</div>
