{% extends "afat/base.html" %}

{% load i18n %}

{% block page_title %}
    {% translate "Fleet Activity Tracking" as page_title %}
    {{ page_title|title }}
{% endblock %}

{% block afat_header %}
    {% translate "Create a FAT link" as site_title %}
    {% include "framework/header/page-header.html" with title=site_title %}
{% endblock %}

{% block afat_body %}
    <div class="row">
        {% include "afat/partials/fatlinks/add/esi-link.html" %}
        {% include "afat/partials/fatlinks/add/clickable-link.html" %}
    </div>
{% endblock %}

{% block afat_datalists %}
    {% include "afat/partials/form/fleet-doctrine.html" %}
    {% include "afat/partials/form/fleet-type.html" %}
{% endblock %}

{% block extra_css %}
    {% include "afat/bundles/afat-css.html" %}
{% endblock %}

{% block extra_javascript %}
    {% include "afat/bundles/afat-js.html" %}
    {% include "afat/bundles/afat-datalist-js.html" %}

    <script>
        $(document).ready(() => {
            const cancelEsiFleetModal = $('#cancelEsiFleetModal');

            manageModal(cancelEsiFleetModal);
        });
    </script>
{% endblock %}
