{% load i18n %}

<ul class="nav nav-tabs">
    {#  We only need the tabs when we have more than one ...  #}
    {% if perms.afat.manage_afat and is_clickable_link and manual_fat_can_be_added %}
        <li class="nav-item" role="presentation">
            <a
                class="nav-link active"
                id="fats"
                data-bs-toggle="tab"
                href="#tab-fats"
                role="tab"
                aria-controls="tab-fats"
                aria-selected="true"
            >
                {% translate "FATs" %}
            </a>
        </li>

        <li class="nav-item" role="presentation">
            <a
                class="nav-link"
                id="manualfat"
                data-bs-toggle="tab"
                href="#tab-manualfat"
                role="tab"
                aria-controls="tab-manualfat"
                aria-selected="true"
            >
                {% translate "Manual FAT" %}
            </a>
        </li>
    {% endif %}
</ul>
